/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2002-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: cloneable.scala 9951 2007-02-09 19:09:06Z odersky $


package scala;


/**
 * An annotation that designates the class to which it is applied as cloneable
 */
class cloneable extends Annotation {}
